Description Usage Arguments Details Value See Also Examples
Choose the top n journals according to the number of submissions in
the REF. The remaining journals are aggregated into a 'super-journal' called
'Other'.
1 | aggregate_outputs(outputs, top_journals = get_top_journals(outputs))
|
outputs |
A data frame like that produced by |
top_journals |
A data frame like that produced by |
To preserve data integrity, each journal is given a new_id, which in
the case of the top n journals is identical to their original
journal_id, in the case of conference proceedings is set equal to
0, in the case of n+1 or less popular journals, is set equal to
-1 and in the case of other non-journal outputs it set equal to
-2. These codes have no particular significance other than avoiding
clashes with the automatically-assigned journal_ids assigned by the
cluster_outputs_by_journals algorithm.
A data frame similar to outputs but with lower-ranked journals
aggregated classes 'Other journals', 'Conference proceedings' or 'Other
outputs' according to their output type.
1 2 3 | math_outputs <- subset(tidy_outputs(), uoa_name == 'Mathematical Sciences')
math_outputs <- cluster_outputs_by_journals(math_outputs)
aggregate_outputs(math_outputs)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.