Description Usage Arguments Value
Convert a title to lower case, and remove spaces, punctuation and accents
1 |
title |
A character vector of volume titles |
A character vector, the same length as the input
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.